##
##  pureftpd.spec -- OpenPKG RPM Package Specification
##  Copyright (c) 2000-2024 OpenPKG Project <http://openpkg.org/>
##
##  Permission to use, copy, modify, and distribute this software for
##  any purpose with or without fee is hereby granted, provided that
##  the above copyright notice and this permission notice appear in all
##  copies.
##
##  THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
##  WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
##  MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
##  IN NO EVENT SHALL THE AUTHORS AND COPYRIGHT HOLDERS AND THEIR
##  CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
##  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
##  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
##  USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
##  ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
##  OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
##  OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
##  SUCH DAMAGE.
##

#   package information
Name:         pureftpd
Summary:      Alternative FTP Server
URL:          http://www.pureftpd.org/
Vendor:       A.Gulbrandsen, Frank DENIS
Packager:     OpenPKG Project
Distribution: OpenPKG Community
Class:        BASE
Group:        FTP
License:      BSD
Version:      1.0.52
Release:      20240918

#   package options
%option       with_fsl        yes
%option       with_pam        no
%option       with_ldap       no
%option       with_mysql      no
%option       with_pgsql      no
%option       with_minimal    no
%option       with_everything no

#   list of sources
Source0:      ftp://ftp.pureftpd.org/pub/pure-ftpd/releases/pure-ftpd-%{version}.tar.gz
Source1:      rc.pureftpd
Source2:      fsl.pureftpd

#   build information
BuildPreReq:  OpenPKG, openpkg >= 20160101, make, gcc
PreReq:       OpenPKG, openpkg >= 20160101
BuildPreReq:  libsodium
PreReq:       libsodium
%if "%{with_fsl}" == "yes"
BuildPreReq:  fsl
PreReq:       fsl
%endif
%if "%{with_pam}" == "yes"
BuildPreReq:  PAM
PreReq:       PAM
%endif
%if "%{with_ldap}" == "yes"
BuildPreReq:  openldap, openssl
PreReq:       openldap, openssl
%endif
%if "%{with_mysql}" == "yes"
BuildPreReq:  mysql
PreReq:       mysql
%endif
%if "%{with_pgsql}" == "yes"
BuildPreReq:  postgresql
PreReq:       postgresql
%endif

%description
    Pure-FTPd is a fast, production-quality, standard-conformant FTP
    server, based upon Troll-FTPd. Unlike other popular FTP servers,
    it's designed to be secure in default configuration, has no known
    buffer overflow, it is really trivial to set up and it is especially
    designed for modern kernels. Features include PAM support, IPv6,
    chroot()ed home directories, virtual domains, built-in 'ls',
    anti-warez system, bounded ports for passive downloads, FXP
    protocol, bandwidth throttling, ratios, LDAP, XML and HTML reports,
    support for external programs to post-process uploads and more.

%track
    prog pureftpd = {
        version   = %{version}
        url       = ftp://ftp.pureftpd.org/pub/pure-ftpd/releases/
        regex     = pure-ftpd-(__VER__)\.tar\.gz
    }

%prep
    %setup -q -n pure-ftpd-%{version}

%build
    CC="%{l_cc}" \
    CFLAGS="%{l_cflags -O}" \
    CPPFLAGS="%{l_cppflags}" \
    LDFLAGS="%{l_fsl_ldflags}" \
    LIBS="%{l_fsl_libs}" \
%if "%{with_pam}" == "yes"
    CPPFLAGS="-I`%{l_rc} --query pam_incdir` %{l_cppflags}" \
    LDFLAGS="-L`%{l_rc} --query pam_libdir` %{l_ldflags}" \
%endif
%if "%{with_ldap}" == "yes"
    LIBS="%{l_fsl_libs} -lldap -llber -lssl -lcrypto" \
%endif
    ./configure \
        --prefix=%{l_prefix} \
        --sysconfdir=%{l_prefix}/etc/pureftpd \
        --without-inetd \
        --without-humor \
        --without-cookie \
        --without-welcomemsg \
%if "%{with_pam}" == "yes"
        --with-pam \
%endif
%if "%{with_ldap}" == "yes"
        --with-ldap=%{l_prefix} \
%endif
%if "%{with_mysql}" == "yes"
        --with-mysql=%{l_prefix} \
%endif
%if "%{with_pgsql}" == "yes"
        --with-pgsql=%{l_prefix} \
%endif
%if "%{with_minimal}" == "yes"
        --with-minimal \
%endif
%if "%{with_everything}" == "yes"
        --with-everything \
%endif
        --with-ftpwho \
        --with-virtualhosts \
        --with-language=english \
        --with-largefile \
        --disable-ssp
    #   workaround broken configure:
    #   "checking whether realpath likes unreadable directories"
    #   can leave a test directory, which is not removable.
    test -d x && chmod 755 x || true
    %{l_make} %{l_mflags -O}

%install
    %{l_shtool} mkdir -f -p -m 755 \
        $RPM_BUILD_ROOT%{l_prefix}/var/pureftpd \
        $RPM_BUILD_ROOT%{l_prefix}/etc/rc.d
    %{l_make} %{l_mflags} install AM_MAKEFLAGS="DESTDIR=$RPM_BUILD_ROOT"
    strip $RPM_BUILD_ROOT%{l_prefix}/bin/* >/dev/null 2>&1 || true
    strip $RPM_BUILD_ROOT%{l_prefix}/sbin/* >/dev/null 2>&1 || true

    #   install run-command script
    %{l_shtool} mkdir -f -p -m 755 \
        $RPM_BUILD_ROOT%{l_prefix}/etc/rc.d
    %{l_shtool} install -c -m 755 %{l_value -s -a} \
        %{SOURCE rc.pureftpd} $RPM_BUILD_ROOT%{l_prefix}/etc/rc.d/

    #   install OSSP fsl configuration
    %{l_shtool} mkdir -f -p -m 755 $RPM_BUILD_ROOT%{l_prefix}/etc/fsl
    %{l_shtool} install -c -m 644 %{l_value -s -a} \
        %{SOURCE fsl.pureftpd} \
        $RPM_BUILD_ROOT%{l_prefix}/etc/fsl/

    #   determine installation files
    %{l_rpmtool} files -v -ofiles -r$RPM_BUILD_ROOT \
        %{l_files_std} \
        '%config %{l_prefix}/etc/fsl/fsl.pureftpd'

%files -f files

%clean

%pre
    #   before upgrade, save status and stop service
    [ $1 -eq 2 ] || exit 0
    eval `%{l_rc} pureftpd status 2>/dev/null | tee %{l_tmpfile}`
    %{l_rc} pureftpd stop 2>/dev/null
    exit 0

%post
%if "%{with_pam}" == "yes"
    if [ $1 -eq 1 ]; then
        #   after install, add PAM configuration entry
        $RPM_INSTALL_PREFIX/sbin/pamtool --add --smart --name=pureftpd
    fi
%endif
    if [ $1 -eq 2 ]; then
        #   after upgrade, restore status
        { eval `cat %{l_tmpfile}`; rm -f %{l_tmpfile}; true; } >/dev/null 2>&1
        [ ".$pureftpd_active" = .yes ] && %{l_rc} pureftpd start
    fi
    exit 0

%preun
    #   before erase, stop service and remove log files
    [ $1 -eq 0 ] || exit 0
    %{l_rc} pureftpd stop 2>/dev/null
    rm -f $RPM_INSTALL_PREFIX/var/pureftpd/pureftpd.log* >/dev/null 2>&1 || true
%if "%{with_pam}" == "yes"
    #   remove PAM configuration entry
    $RPM_INSTALL_PREFIX/sbin/pamtool --remove --smart --name=pureftpd
%endif
    exit 0

